@@ -1,10 +1,5 @@
 package WordList::Test::Dynamic::OneTwo_EachParam;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-23'; # DATE
-our $DIST = 'WordList'; # DIST
-our $VERSION = '0.7.10'; # VERSION
-
 use strict;
 
 use WordList::Test::Dynamic::OneTwo_Each;
@@ -13,6 +8,11 @@ our @ISA = qw(WordList::Test::Dynamic::OneTwo_Each);
 use Role::Tiny::With;
 with 'WordListRole::FirstNextResetFromEach';
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-26'; # DATE
+our $DIST = 'WordList'; # DIST
+our $VERSION = '0.7.11'; # VERSION
+
 our $DYNAMIC = 1;
 
 our %PARAMS = (
@@ -38,7 +38,7 @@ WordList::Test::Dynamic::OneTwo_EachParam - Wordlist that returns one, two (via
 
 =head1 VERSION
 
-This document describes version 0.7.10 of WordList::Test::Dynamic::OneTwo_EachParam (from Perl distribution WordList), released on 2021-06-23.
+This document describes version 0.7.11 of WordList::Test::Dynamic::OneTwo_EachParam (from Perl distribution WordList), released on 2021-09-26.
 
 =head1 SYNOPSIS
 
@@ -99,6 +99,34 @@ Please visit the project's homepage at L<https://metacpan.org/release/WordList>.
 
 Source repository is at L<https://github.com/perlancar/perl-WordList>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2021, 2020, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordList>
@@ -107,15 +135,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2018, 2017, 2016 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
