@@ -1,12 +1,12 @@
 package WordListBase;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-23'; # DATE
-our $DIST = 'WordList'; # DIST
-our $VERSION = '0.7.10'; # VERSION
-
 use strict 'subs', 'vars';
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-09-26'; # DATE
+our $DIST = 'WordList'; # DIST
+our $VERSION = '0.7.11'; # VERSION
+
 sub new {
     my $class = shift;
 
@@ -49,7 +49,7 @@ WordListBase - WordList base class
 
 =head1 VERSION
 
-This document describes version 0.7.10 of WordListBase (from Perl distribution WordList), released on 2021-06-23.
+This document describes version 0.7.11 of WordListBase (from Perl distribution WordList), released on 2021-09-26.
 
 =head1 DESCRIPTION
 
@@ -67,14 +67,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/WordList>.
 
 Source repository is at L<https://github.com/perlancar/perl-WordList>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordList>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<WordList>
@@ -83,11 +75,36 @@ L<WordList>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020, 2018, 2017, 2016 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2018, 2017, 2016 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=WordList>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
